import { endOfDay, isAfter, isBefore, startOfDay, isSameDay } from 'date-fns';
import { parseBase } from './index';
function generateNumberArray(max) {
    return Array.from({ length: max + 1 }, function (_, i) { return i; });
}
export default function unifiedDisabledDateFromProps(format, disabledDateProps, disabledTime) {
    if (typeof disabledTime === 'function') {
        return disabledTime;
    }
    if (typeof disabledDateProps === 'object') {
        var _a = disabledDateProps, min_1 = _a.min, max_1 = _a.max;
        var disabledDate_1 = function (date) {
            return (!!min_1 && isBefore(endOfDay(date), parseBase(min_1, format))) ||
                (!!max_1 && isAfter(startOfDay(date), parseBase(max_1, format)));
        };
        return function (date) {
            var isDateDisabled = disabledDate_1(date);
            if (isDateDisabled) {
                return {
                    disabledHours: function () { return generateNumberArray(23); },
                    disabledMinutes: function () { return generateNumberArray(59); },
                    disabledSeconds: function () { return generateNumberArray(59); },
                };
            }
            if (!!min_1 && isSameDay(endOfDay(date), parseBase(min_1, format))) {
                var minDate_1 = parseBase(min_1, format);
                return {
                    disabledHours: function () { return generateNumberArray(minDate_1.getHours() - 1); },
                    disabledMinutes: function (hour) {
                        return hour === minDate_1.getHours()
                            ? generateNumberArray(minDate_1.getMinutes() - 1)
                            : [];
                    },
                    disabledSeconds: function (hour, minute) {
                        return hour === minDate_1.getHours() && minute === minDate_1.getMinutes()
                            ? generateNumberArray(minDate_1.getSeconds() - 1)
                            : [];
                    },
                };
            }
            if (!!max_1 && isSameDay(startOfDay(date), parseBase(max_1, format))) {
                var maxDate_1 = parseBase(max_1, format);
                return {
                    disabledHours: function () {
                        return generateNumberArray(23).slice(maxDate_1.getHours() + 1);
                    },
                    disabledMinutes: function (hour) {
                        return hour === maxDate_1.getHours()
                            ? generateNumberArray(59).slice(maxDate_1.getMinutes() + 1)
                            : [];
                    },
                    disabledSeconds: function (hour, minute) {
                        return hour === maxDate_1.getHours() && minute === maxDate_1.getMinutes()
                            ? generateNumberArray(59).slice(maxDate_1.getSeconds() + 1)
                            : [];
                    },
                };
            }
            return {
                disabledHours: function () { return []; },
                disabledMinutes: function () { return []; },
                disabledSeconds: function () { return []; },
            };
        };
    }
    return disabledTime;
}
